<?php

namespace Offerte\Offerte\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Offerte\Offerte\Http\Requests\TestModuleRequest;
use Offerte\Offerte\Interfaces\TestModuleRepositoryInterface;
use Offerte\Offerte\Models\TestModule;

/**
 * Resource controller class for test_module.
 */
class TestModuleResourceController extends BaseController
{

    /**
     * Initialize test_module resource controller.
     *
     * @param type TestModuleRepositoryInterface $test_module
     *
     * @return null
     */
    public function __construct(TestModuleRepositoryInterface $test_module)
    {
        parent::__construct();
        $this->repository = $test_module;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Offerte\Offerte\Repositories\Criteria\TestModuleResourceCriteria::class);
    }

    /**
     * Display a list of test_module.
     *
     * @return Response
     */
    public function index(TestModuleRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Offerte\Offerte\Repositories\Presenter\TestModulePresenter::class)
                ->$function();
        }

        $test_modules = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('offerte::test_module.names'))
            ->view('offerte::test_module.index', true)
            ->data(compact('test_modules', 'view'))
            ->output();
    }

    /**
     * Display test_module.
     *
     * @param Request $request
     * @param Model   $test_module
     *
     * @return Response
     */
    public function show(TestModuleRequest $request, TestModule $test_module)
    {

        if ($test_module->exists) {
            $view = 'offerte::test_module.show';
        } else {
            $view = 'offerte::test_module.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('offerte::test_module.name'))
            ->data(compact('test_module'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new test_module.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TestModuleRequest $request)
    {

        $test_module = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('offerte::test_module.name')) 
            ->view('offerte::test_module.create', true) 
            ->data(compact('test_module'))
            ->output();
    }

    /**
     * Create new test_module.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TestModuleRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $test_module                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('offerte::test_module.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('offerte/test_module/' . $test_module->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/offerte/test_module'))
                ->redirect();
        }

    }

    /**
     * Show test_module for editing.
     *
     * @param Request $request
     * @param Model   $test_module
     *
     * @return Response
     */
    public function edit(TestModuleRequest $request, TestModule $test_module)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('offerte::test_module.name'))
            ->view('offerte::test_module.edit', true)
            ->data(compact('test_module'))
            ->output();
    }

    /**
     * Update the test_module.
     *
     * @param Request $request
     * @param Model   $test_module
     *
     * @return Response
     */
    public function update(TestModuleRequest $request, TestModule $test_module)
    {
        try {
            $attributes = $request->all();

            $test_module->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('offerte::test_module.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('offerte/test_module/' . $test_module->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('offerte/test_module/' . $test_module->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the test_module.
     *
     * @param Model   $test_module
     *
     * @return Response
     */
    public function destroy(TestModuleRequest $request, TestModule $test_module)
    {
        try {

            $test_module->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('offerte::test_module.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('offerte/test_module/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('offerte/test_module/' . $test_module->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple test_module.
     *
     * @param Model   $test_module
     *
     * @return Response
     */
    public function delete(TestModuleRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('offerte::test_module.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('offerte/test_module'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/offerte/test_module'))
                ->redirect();
        }

    }

    /**
     * Restore deleted test_modules.
     *
     * @param Model   $test_module
     *
     * @return Response
     */
    public function restore(TestModuleRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('offerte::test_module.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/offerte/test_module'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/offerte/test_module/'))
                ->redirect();
        }

    }

}
